# import filters into this namespace
from omdox.filters import *


# set up the defaults
# exclude these directories
EXCLUDED_DIRNAMES = (
    '_build',
)
# the blocks to parse for code and markdown
CONTENT_BLOCK = 'content'
# exclude these files
EXCLUDED_FILENAMES = (
    'layout.html',
)
# use these filters when rendering
FILTERS = (
   'pygmentize',
   'markdown',
)

# overwrite the defaults from local conf
try:
    from conf import *
except ImportError:
    pass



import re
import pygments
from pygments import lexers, formatters
from bs4 import BeautifulSoup
import markdown as md


def markdown(content):
    return md.markdown(content)


def pygmentize(content):
    code_regex = re.compile(r'(<code(.*?)</code>)', re.DOTALL)
    code_blocks = []
    for i, m in enumerate(code_regex.finditer(content)):
        code = m.group(0)
        # if there is a lang attribute, use that
        if code.find('lang') > 0:
            soup = BeautifulSoup(code)
            language = soup.code['lang'] 
            # TODO: catch errors here and provide a default lexer
            lexer = lexers.get_lexer_by_name(language)
            # remove the code tags
            code = code.replace('</code>', '')
            code = code.replace('<code>', '')
            code = re.sub('<code(.*?)>', '', code)
            # create the pygmented code with the lexer
            pygmented_string = pygments.highlight(
                    code,
                    lexer,
                    formatters.HtmlFormatter())
            # put the code blocks into the list for processintg later
            code_blocks.append(pygmented_string)
        else:
            # this is for the inline code snippets
            code_blocks.append(code)
        # replace <code> tags with placeholders 
        content = content.replace(
                m.string[m.start():m.end()], 'OMCB|%s|OMCB' % i)
    # now do the replace
    for i, code in enumerate(code_blocks):
        content = content.replace('<p>OMCB|%s|OMCB</p>' % i, code)
        content = content.replace('OMCB|%s|OMCB' % i, code)
    return content



import os
from distutils.core import setup
from omdox import get_version

root_dir = os.path.dirname(__file__)
if root_dir != '':
    os.chdir(root_dir)

setup(
    name='omdox',
    version=get_version(),
    license = 'BSD 3 Clause',
    description='A lightweight documentation builder.',
    long_description=open('README.md').read(),
    author='Obscure Metaphor',
    url='https://github.com/obscuremetaphor/omdox',
    author_email='hello@obscuremetaphor.co.uk',
    packages=[
        'omdox',
    ],
    classifiers=[
        'Topic :: Documentation',
        'Development Status :: 3 - Alpha',
        'Topic :: Software Development :: Documentation',
    ],
    scripts=[
        'bin/omdox'
    ],
    install_requires = [
        'jinja2',
        'pygments',
        'beautifulsoup4',
        'markdown']
)
